const puzzleContainer = document.getElementById('puzzleContainer');
const resetButton = document.getElementById('resetButton');
const victoryMessage = document.getElementById('victoryMessage');
let emptyIndex = 8;

const pieces = Array.from(puzzleContainer.children);

const shufflePuzzle = () => {
  pieces.sort(() => Math.random() - 0.5);
  pieces.forEach((piece, index) => {
    piece.style.order = index;
    piece.dataset.index = index;
    if (!piece.textContent) {
      emptyIndex = index;
    }
  });
};

const checkWin = () => {
  const isWin = pieces.every((piece, index) => piece.textContent == index + 1 || index === 8);
  if (isWin) {
    victoryMessage.classList.add('show');
  }
};

const movePiece = (index) => {
  const piece = pieces[index];
  const emptyPiece = pieces[emptyIndex];
  if (Math.abs(index - emptyIndex) === 1 || Math.abs(index - emptyIndex) === 3) {
    [piece.style.order, emptyPiece.style.order] = [emptyPiece.style.order, piece.style.order];
    [pieces[index], pieces[emptyIndex]] = [pieces[emptyIndex], pieces[index]];
    emptyIndex = index;
    checkWin();
  }
};

pieces.forEach((piece, index) => {
  piece.addEventListener('click', () => movePiece(index));
});

resetButton.addEventListener('click', () => {
  shufflePuzzle();
  victoryMessage.classList.remove('show');
});

shufflePuzzle();